@@ -18,8 +18,8 @@
 #include "operation.h"
 #include "umldoc.h"
 
-#include <QtCore/QRegExp>
-#include <QtCore/QTextStream>
+#include <QRegExp>
+#include <QTextStream>
 
 static const char *reserved_words[] = {
     "abs",
@@ -692,8 +692,8 @@ void ASWriter::writeAssociation(QString& classname, UMLAssociationList& assocLis
             }
 
             bool okCvt;
-            int nMulti = a->getMulti(role).toInt(&okCvt,10);
-            bool isNotMulti = a->getMulti(role).isEmpty() || (okCvt && nMulti == 1);
+            int nMulti = a->getMultiplicity(role).toInt(&okCvt,10);
+            bool isNotMulti = a->getMultiplicity(role).isEmpty() || (okCvt && nMulti == 1);
 
             QString typeName(cleanName(a->getObject(role)->name()));
 
