@@ -20,47 +20,38 @@
 #include "uml.h"
 
 // qt includes
-#include <QtGui/QPainter>
-#include <QtXml/QDomDocument>
+#include <QDomDocument>
+#include <QPainter>
 
 // system includes
 #include <cstdlib>
 #include <cmath>
 
+DEBUG_REGISTER_DISABLED(AssociationLine)
+
 AssociationLine::Circle::Circle(int radius /* = 0 */)
-  : UMLSceneEllipseItem(radius * 2, radius * 2)
+  : QGraphicsEllipseItem(0, 0, radius * 2, radius * 2)
 {
 }
-
-void AssociationLine::Circle::setX(int x)
-{
-    UMLSceneItem::setX( (double) x );
-}
-
-void AssociationLine::Circle::setY(int y)
-{
-    UMLSceneItem::setY( (double) y );
-}
-
 void AssociationLine::Circle::setRadius(int radius)
 {
-    UMLSceneEllipseItem::setSize(radius * 2, radius * 2);
+    QGraphicsEllipseItem::setRect(x(), y(), radius * 2, radius * 2);
 }
 
 int AssociationLine::Circle::getRadius() const
 {
-    return (UMLSceneEllipseItem::height() / 2);
+    return rect().height() / 2;
 }
 
 void AssociationLine::Circle::drawShape(QPainter& p)
 {
-    int diameter = height();
+    int diameter = rect().height();
     int radius = diameter / 2;
     p.drawEllipse( (int)x() - radius, (int)y() - radius, diameter, diameter);
 }
 
 AssociationLine::SubsetSymbol::SubsetSymbol()
-  : UMLSceneEllipseItem()
+  : QGraphicsEllipseItem()
 {
     inclination = 0;
 }
@@ -105,24 +96,24 @@ AssociationLine::~AssociationLine()
 /**
  * Returns the point at the point index.
  */
-QPoint AssociationLine::point(int pointIndex) const 
+UMLScenePoint AssociationLine::point(int pointIndex) const
 {
     int count = m_LineList.count();
     if( count == 0 || pointIndex > count  || pointIndex < 0)
-        return QPoint( -1, -1 );
+        return UMLScenePoint( -1, -1 );
 
     if( pointIndex == count ) {
-        UMLSceneLineItem * line = m_LineList.last();
-        return line->endPoint();
+        QGraphicsLineItem* line = m_LineList.last();
+        return line->line().p2();
     }
-    UMLSceneLineItem * line = m_LineList.at( pointIndex );
-    return line->startPoint();
+    QGraphicsLineItem* line = m_LineList.at( pointIndex );
+    return line->line().p1();
 }
 
 /**
  * Sets the position of an already set point.
  */
-bool AssociationLine::setPoint(int pointIndex, const QPoint &point)
+bool AssociationLine::setPoint(int pointIndex, const UMLScenePoint &point)
 {
     int count = m_LineList.count();
     if( count == 0 || pointIndex > count  || pointIndex < 0)
@@ -133,27 +124,27 @@ bool AssociationLine::setPoint(int pointIndex, const QPoint &point)
     }
 
     if( pointIndex == count) {
-        UMLSceneLineItem * line = m_LineList.last();
-        QPoint p = line->startPoint();
-        line->setPoints( p.x(), p.y(), point.x(), point.y() );
+        QGraphicsLineItem* line = m_LineList.last();
+        UMLScenePoint p = line->line().p1();
+        line->setLine( p.x(), p.y(), point.x(), point.y() );
         moveSelected( pointIndex );
         update();
         return true;
     }
     if( pointIndex == 0 ) {
-        UMLSceneLineItem * line = m_LineList.first();
-        QPoint p = line->endPoint();
-        line->setPoints( point.x(), point.y(), p.x(), p.y() );
+        QGraphicsLineItem* line = m_LineList.first();
+        UMLScenePoint p = line->line().p2();
+        line->setLine( point.x(), point.y(), p.x(), p.y() );
         moveSelected( pointIndex );
         update();
         return true;
     }
-    UMLSceneLineItem * line = m_LineList.at( pointIndex  );
-    QPoint p = line->endPoint();
-    line->setPoints( point.x(), point.y(), p.x(), p.y() );
+    QGraphicsLineItem* line = m_LineList.at( pointIndex  );
+    UMLScenePoint p = line->line().p2();
+    line->setLine( point.x(), point.y(), p.x(), p.y() );
     line = m_LineList.at( pointIndex - 1 );
-    p = line->startPoint();
-    line->setPoints( p.x(), p.y(), point.x(), point.y() );
+    p = line->line().p1();
+    line->setLine( p.x(), p.y(), point.x(), point.y() );
     moveSelected( pointIndex );
     update();
     return true;
@@ -162,7 +153,7 @@ bool AssociationLine::setPoint(int pointIndex, const QPoint &point)
 /**
  * Shortcut for point(0).
  */
-QPoint AssociationLine::startPoint() const
+UMLScenePoint AssociationLine::startPoint() const
 {
     return point(0);
 }
@@ -170,7 +161,7 @@ QPoint AssociationLine::startPoint() const
 /**
  * Shortcut for point(count()-1).
  */
-QPoint AssociationLine::endPoint() const
+UMLScenePoint AssociationLine::endPoint() const
 {
     return point(count()-1);
 }
@@ -178,7 +169,7 @@ QPoint AssociationLine::endPoint() const
 /**
  * Inserts a point at the given index.
  */
-bool AssociationLine::insertPoint(int pointIndex, const QPoint &point)
+bool AssociationLine::insertPoint(int pointIndex, const UMLScenePoint &point)
 {
     int count = m_LineList.count();
     if( count == 0 )
@@ -186,14 +177,14 @@ bool AssociationLine::insertPoint(int pointIndex, const QPoint &point)
     const bool bLoading = UMLApp::app()->document()->loading();
 
     if( count == 1 || pointIndex == 1) {
-        UMLSceneLineItem * first = m_LineList.first();
-        QPoint sp = first->startPoint();
-        QPoint ep = first->endPoint();
-        first->setPoints( sp.x(), sp.y(), point.x(), point.y() );
-        UMLSceneLineItem * line = new UMLSceneLineItem;
-        line->setCanvas(canvas());
-        line->setZ( -2 );
-        line->setPoints( point.x(), point.y(), ep.x(), ep.y() );
+        QGraphicsLineItem* first = m_LineList.first();
+        UMLScenePoint sp = first->line().p1();
+        UMLScenePoint ep = first->line().p2();
+        first->setLine( sp.x(), sp.y(), point.x(), point.y() );
+        QGraphicsLineItem* line = new QGraphicsLineItem;
+        canvas()->addItem(line);
+        line->setZValue( -2 );
+        line->setLine( point.x(), point.y(), ep.x(), ep.y() );
         line->setPen( pen() );
         line->setVisible( true );
         m_LineList.insert( 1, line );
@@ -202,14 +193,14 @@ bool AssociationLine::insertPoint(int pointIndex, const QPoint &point)
         return true;
     }
     if( count + 1 == pointIndex ) {
-        UMLSceneLineItem * before = m_LineList.last();
-        QPoint sp = before->startPoint();
-        QPoint ep = before->endPoint();
-        before->setPoints( sp.x(), sp.y(), point.x(), point.y() );
-        UMLSceneLineItem * line = new UMLSceneLineItem;
-        line->setCanvas(canvas());
-        line->setPoints( point.x(), point.y(), ep.x(), ep.y() );
-        line->setZ( -2 );
+        QGraphicsLineItem* before = m_LineList.last();
+        UMLScenePoint sp = before->line().p1();
+        UMLScenePoint ep = before->line().p2();
+        before->setLine( sp.x(), sp.y(), point.x(), point.y() );
+        QGraphicsLineItem* line = new QGraphicsLineItem;
+        canvas()->addItem(line);
+        line->setLine( point.x(), point.y(), ep.x(), ep.y() );
+        line->setZValue( -2 );
         line->setPen( pen() );
         line->setVisible( true );
         m_LineList.append( line );
@@ -217,14 +208,14 @@ bool AssociationLine::insertPoint(int pointIndex, const QPoint &point)
             setupSelected();
         return true;
     }
-    UMLSceneLineItem * before = m_LineList.at( pointIndex - 1 );
-    QPoint sp = before->startPoint();
-    QPoint ep = before->endPoint();
-    before->setPoints( sp.x(), sp.y(), point.x(), point.y() );
-    UMLSceneLineItem * line = new UMLSceneLineItem;
-    line->setCanvas(canvas());
-    line->setPoints( point.x(), point.y(), ep.x(), ep.y() );
-    line->setZ( -2 );
+    QGraphicsLineItem* before = m_LineList.at( pointIndex - 1 );
+    UMLScenePoint sp = before->line().p1();
+    UMLScenePoint ep = before->line().p2();
+    before->setLine( sp.x(), sp.y(), point.x(), point.y() );
+    QGraphicsLineItem* line = new QGraphicsLineItem;
+    canvas()->addItem(line);
+    line->setLine( point.x(), point.y(), ep.x(), ep.y() );
+    line->setZValue( -2 );
     line->setPen( pen() );
     line->setVisible( true );
     m_LineList.insert( pointIndex, line );
@@ -237,7 +228,7 @@ bool AssociationLine::insertPoint(int pointIndex, const QPoint &point)
  * Removes the point on the line given by the index, at the coordinates
  * given by point with a fuzzy of delta.
  */
-bool AssociationLine::removePoint(int pointIndex, const QPoint &point, unsigned short delta)
+bool AssociationLine::removePoint(int pointIndex, const UMLScenePoint &point, unsigned short delta)
 {
     /* get the number of line segments */
     int count = m_LineList.count();
@@ -247,10 +238,10 @@ bool AssociationLine::removePoint(int pointIndex, const QPoint &point, unsigned
     if (!point.isNull()) {
         /* we don't know if the user clicked on the start- or endpoint of a
         * line segment */
-        UMLSceneLineItem * current_line = m_LineList.at( pointIndex );
-        if (abs( current_line->endPoint().x() - point.x() ) <= delta
+        QGraphicsLineItem* current_line = m_LineList.at( pointIndex );
+        if (abs( current_line->line().p2().x() - point.x() ) <= delta
                 &&
-                abs( current_line->endPoint().y() - point.y() ) <= delta)
+                abs( current_line->line().p2().y() - point.y() ) <= delta)
         {
             /* the user clicked on the end point of the line;
             * we have to make sure that this isn't the last line segment */
@@ -259,29 +250,29 @@ bool AssociationLine::removePoint(int pointIndex, const QPoint &point, unsigned
 
             /* the next segment will get the starting point from the current one,
             * which is going to be removed */
-            UMLSceneLineItem * next_line = m_LineList.at( pointIndex + 1 );
-            QPoint startPoint = current_line->startPoint();
-            QPoint endPoint = next_line->endPoint();
-            next_line->setPoints(startPoint.x(), startPoint.y(),
-                                endPoint.x(), endPoint.y());
+            QGraphicsLineItem* next_line = m_LineList.at( pointIndex + 1 );
+            UMLScenePoint startPoint = current_line->line().p1();
+            UMLScenePoint endPoint = next_line->line().p2();
+            next_line->setLine(startPoint.x(), startPoint.y(),
+                               endPoint.x(), endPoint.y());
 
         } else
-            if (abs( current_line->startPoint().x() - point.x() ) <= delta
+            if (abs( current_line->line().p1().x() - point.x() ) <= delta
                     &&
-                    abs( current_line->startPoint().y() - point.y() ) <= delta)
+                    abs( current_line->line().p1().y() - point.y() ) <= delta)
             {
-                /* the user clicked on the start point of the line;
-                * we have to make sure that this isn't the first line segment */
+                // the user clicked on the start point of the line;
+                // we have to make sure that this isn't the first line segment
                 if (pointIndex < 1)
                     return false;
 
-                /* the previous segment will get the end point from the current one,
-                * which is going to be removed */
-                UMLSceneLineItem * previous_line = m_LineList.at( pointIndex - 1 );
-                QPoint startPoint = previous_line->startPoint();
-                QPoint endPoint = current_line->endPoint();
-                previous_line->setPoints(startPoint.x(), startPoint.y(),
-                                        endPoint.x(), endPoint.y());
+                // the previous segment will get the end point from the current one,
+                // which is going to be removed
+                QGraphicsLineItem* previous_line = m_LineList.at( pointIndex - 1 );
+                UMLScenePoint startPoint = previous_line->line().p1();
+                UMLScenePoint endPoint = current_line->line().p2();
+                previous_line->setLine(startPoint.x(), startPoint.y(),
+                                       endPoint.x(), endPoint.y());
             } else {
                 /* the user clicked neither on the start- nor on the end point of
                 * the line; this really shouldn't happen, but just make sure */
@@ -347,14 +338,14 @@ void AssociationLine::cleanup()
  * @retval "Index" of the linepoint closest to the \a point passed.
  * @retval -1 If no linepoint is closer to passed in \a point.
  */
-int AssociationLine::closestPointIndex(const QPoint &position)
+int AssociationLine::closestPointIndex(const UMLScenePoint &position)
 {
     UMLSceneItemList list = canvas()->collisions( position );
     int index = -1;
 
     UMLSceneItemList::iterator end(list.end());
     for(UMLSceneItemList::iterator item_it(list.begin()); item_it != end; ++item_it ) {
-        if( ( index = m_LineList.indexOf( (UMLSceneLineItem*)*item_it ) ) != -1 )
+        if( ( index = m_LineList.indexOf( (QGraphicsLineItem*)*item_it ) ) != -1 )
             break;
     }//end for
     return index;
@@ -365,41 +356,41 @@ int AssociationLine::closestPointIndex(const QPoint &position)
  * We use the delta, because with the mouse it is hard to find the
  * exactly point.
  */
-bool AssociationLine::isPoint(int pointIndex, const QPoint &point, unsigned short delta)
+bool AssociationLine::isPoint(int pointIndex, const UMLScenePoint &point, unsigned short delta)
 {
     int count = m_LineList.count();
     if ( pointIndex >= count )
         return false;
 
-    UMLSceneLineItem * line = m_LineList.at( pointIndex );
+    QGraphicsLineItem* line = m_LineList.at( pointIndex );
 
-    /* check if the given point is the start or end point of the line */
+    // check if the given point is the start or end point of the line
     if ( (
-                abs( line->endPoint().x() - point.x() ) <= delta
+                abs( line->line().p2().x() - point.x() ) <= delta
                 &&
-                abs( line->endPoint().y() - point.y() ) <= delta
+                abs( line->line().p2().y() - point.y() ) <= delta
             ) || (
-                abs( line->startPoint().x() - point.x() ) <= delta
+                abs( line->line().p1().x() - point.x() ) <= delta
                 &&
-                abs( line->startPoint().y() - point.y() ) <= delta
+                abs( line->line().p1().y() - point.y() ) <= delta
             ) )
         return true;
 
-    /* check if the given point is the start or end point of the line */
+    // check if the given point is the start or end point of the line
     return false;
 }
 
 /**
  * Sets the start and end points.
  */
-bool AssociationLine::setEndPoints(const QPoint &start, const QPoint &end)
+bool AssociationLine::setEndPoints(const UMLScenePoint &start, const UMLScenePoint &end)
 {
     int count = m_LineList.count();
     if( count == 0 ) {
-        UMLSceneLineItem * line = new UMLSceneLineItem;
-        line->setCanvas(canvas());
-        line->setPoints( start.x(), start.y(),end.x(),end.y() );
-        line->setZ( -2 );
+        QGraphicsLineItem* line = new QGraphicsLineItem;
+        canvas()->addItem(line);
+        line->setLine( start.x(), start.y(),end.x(),end.y() );
+        line->setZValue( -2 );
         line->setPen( pen() );
         line->setVisible( true );
         m_LineList.append( line );
@@ -423,8 +414,8 @@ void AssociationLine::dumpPoints()
 {
     int count = m_LineList.count();
     for( int i = 1; i < count; i++ ) {
-        QPoint p = point( i );
-        uDebug()<<" * point x:"<<p.x()<<" y:"<<p.y();
+        UMLScenePoint p = point( i );
+        DEBUG(DBG_SRC) <<" * point x:"<<p.x()<<" y:"<<p.y();
     }
 }
 
@@ -442,7 +433,7 @@ bool AssociationLine::loadFromXMI(QDomElement &qElement)
     int nX = x.toInt();
     QString y = startElement.attribute( "starty", "0" );
     int nY = y.toInt();
-    QPoint startPoint( nX, nY );
+    UMLScenePoint startPoint( nX, nY );
 
     node = startElement.nextSibling();
     QDomElement endElement = node.toElement();
@@ -453,9 +444,9 @@ bool AssociationLine::loadFromXMI(QDomElement &qElement)
     nX = x.toInt();
     y = endElement.attribute( "endy", "0" );
     nY = y.toInt();
-    QPoint endPoint( nX, nY );
+    UMLScenePoint endPoint( nX, nY );
     setEndPoints( startPoint, endPoint );
-    QPoint point;
+    UMLScenePoint point;
     node = endElement.nextSibling();
     QDomElement element = node.toElement();
     int i = 1;
@@ -481,7 +472,7 @@ bool AssociationLine::loadFromXMI(QDomElement &qElement)
 void AssociationLine::saveToXMI(QDomDocument &qDoc, QDomElement &qElement)
 {
     int count = m_LineList.count();
-    QPoint p = point( 0 );
+    UMLScenePoint p = point( 0 );
     QDomElement lineElement = qDoc.createElement( "linepath" );
     QDomElement startElement = qDoc.createElement( "startpoint" );
     startElement.setAttribute( "startx", p.x() );
@@ -534,7 +525,7 @@ QColor AssociationLine::lineColor()
 void AssociationLine::setLineColor(const QColor &color)
 {
     uint linewidth = 0;
-    UMLSceneLineItem * line = 0;
+    QGraphicsLineItem* line = 0;
 
     Q_FOREACH( line, m_LineList ) {
         linewidth = line->pen().width();
@@ -596,7 +587,7 @@ uint AssociationLine::lineWidth()
 void AssociationLine::setLineWidth(uint width)
 {
     QColor linecolor;
-    UMLSceneLineItem * line = 0;
+    QGraphicsLineItem* line = 0;
 
     Q_FOREACH( line, m_LineList ) {
         linecolor = line->pen().color();
@@ -662,8 +653,8 @@ Uml::AssociationType AssociationLine::getAssocType() const
  */
 void AssociationLine::setAssocType(Uml::AssociationType type)
 {
-    QList<UMLSceneLineItem*>::Iterator it = m_LineList.begin();
-    QList<UMLSceneLineItem*>::Iterator end = m_LineList.end();
+    QList<QGraphicsLineItem*>::Iterator it = m_LineList.begin();
+    QList<QGraphicsLineItem*>::Iterator end = m_LineList.end();
 
     for( ; it != end; ++it )
         (*it)->setPen( pen() );
@@ -758,8 +749,8 @@ void AssociationLine::activate()
     if (canvas() == NULL)
         return;
     for (int i = 0; i < count ; i++) {
-        UMLSceneLineItem *line = m_LineList.at(i);
-        line->setCanvas( canvas() );
+        QGraphicsLineItem *line = m_LineList.at(i);
+        canvas()->addItem(line);
         line->setPen( pen() );
     }
 }
@@ -822,7 +813,7 @@ void AssociationLine::slotLineWidthChanged(Uml::IDType viewID)
  * This class doesn't hold this information but is a wrapper
  * method to stop calls to undefined variable like m_associationWidget.
  */
-Q3Canvas* AssociationLine::canvas()
+UMLScene* AssociationLine::canvas()
 {
     if( !m_associationWidget )
         return 0;
@@ -842,23 +833,23 @@ void AssociationLine::moveSelected(int pointIndex)
     }
     if( (int)m_RectList.count() + 1 != lineCount )
         setupSelected();
-    UMLSceneRectItem * rect = 0;
-    UMLSceneLineItem * line = 0;
+    QGraphicsRectItem* rect = 0;
+    QGraphicsLineItem* line = 0;
     if( pointIndex == lineCount || lineCount == 1) {
         line = m_LineList.last();
-        QPoint p = line->endPoint();
+        UMLScenePoint p = line->line().p2();
         rect = m_RectList.last();
         rect->setX( p.x() );
         rect->setY( p.y() );
-        rect->setZ( 4 );
+        rect->setZValue( 4 );
         return;
     }
     line = m_LineList.at( pointIndex );
-    QPoint p = line->startPoint();
+    UMLScenePoint p = line->line().p1();
     rect = m_RectList.at( pointIndex );
     rect->setX( p.x() );
     rect->setY( p.y() );
-    rect->setZ( 4 );
+    rect->setZValue( 4 );
 }
 
 /**
@@ -868,17 +859,17 @@ void AssociationLine::setupSelected()
 {
     qDeleteAll( m_RectList.begin(), m_RectList.end() );
     m_RectList.clear();
-    UMLSceneLineItem * line = 0;
+    QGraphicsLineItem* line = 0;
 
     Q_FOREACH( line, m_LineList ) {
-        QPoint sp = line->startPoint();
-        UMLSceneRectItem *rect = Widget_Utils::decoratePoint(sp);
+        UMLScenePoint sp = line->line().p1();
+        QGraphicsRectItem *rect = Widget_Utils::decoratePoint(sp);
         m_RectList.append( rect );
     }
     //special case for last point
     line = m_LineList.last();
-    QPoint p = line->endPoint();
-    UMLSceneRectItem *rect = Widget_Utils::decoratePoint(p);
+    UMLScenePoint p = line->line().p2();
+    QGraphicsRectItem *rect = Widget_Utils::decoratePoint(p);
     m_RectList.append( rect );
     update();
 }
@@ -889,7 +880,7 @@ void AssociationLine::setupSelected()
 void AssociationLine::calculateHead()
 {
     uint size = m_LineList.count();
-    QPoint farPoint;
+    UMLScenePoint farPoint;
     int halfLength = 10;
     double arrowAngle = 0.2618;   // 0.5 * atan(sqrt(3.0) / 3.0) = 0.2618
     Uml::AssociationType at = getAssocType();
@@ -953,18 +944,18 @@ void AssociationLine::calculateHead()
     m_MidPoint.setX( (int)rint(xb + cosx) );
     m_MidPoint.setY( (int)rint(yb + siny) );
 
-    m_PointArray.setPoint(0, m_EgdePoint);
-    m_PointArray.setPoint(1, m_ArrowPointA);
+    m_PointArray.replace(0, m_EgdePoint);
+    m_PointArray.replace(1, m_ArrowPointA);
     if( getAssocType() == Uml::AssociationType::Realization ||
             getAssocType() == Uml::AssociationType::Generalization ) {
-        m_PointArray.setPoint( 2, m_ArrowPointB );
-        m_PointArray.setPoint( 3, m_EgdePoint );
+        m_PointArray.replace( 2, m_ArrowPointB );
+        m_PointArray.replace( 3, m_EgdePoint );
     } else {
-        QPoint diamondFarPoint;
+        UMLScenePoint diamondFarPoint;
         diamondFarPoint.setX( (int)rint(xb + cosx * 2) );
         diamondFarPoint.setY( (int)rint(yb + siny * 2) );
-        m_PointArray.setPoint(2, diamondFarPoint);
-        m_PointArray.setPoint(3, m_ArrowPointB);
+        m_PointArray.replace(2, diamondFarPoint);
+        m_PointArray.replace(3, m_ArrowPointB);
     }
 
 }
@@ -989,31 +980,31 @@ void AssociationLine::createHeadLines()
     case Uml::AssociationType::Generalization:
     case Uml::AssociationType::Realization:
         growList(m_HeadList, 3);
-        m_pClearPoly = new UMLScenePolygonItem;
-        m_pClearPoly->setCanvas( canvas() );
+        m_pClearPoly = new QGraphicsPolygonItem;
+        canvas()->addItem(m_pClearPoly);
         m_pClearPoly->setVisible( true );
         m_pClearPoly->setBrush( QBrush( Qt::white ) );
-        m_pClearPoly->setZ( -1 );
+        m_pClearPoly->setZValue( -1 );
         break;
 
     case Uml::AssociationType::Composition:
     case Uml::AssociationType::Aggregation:
         growList(m_HeadList, 4);
-        m_pClearPoly = new UMLScenePolygonItem;
-        m_pClearPoly->setCanvas( canvas() );
+        m_pClearPoly = new QGraphicsPolygonItem;
+        canvas()->addItem(m_pClearPoly);
         m_pClearPoly->setVisible( true );
         if( getAssocType() == Uml::AssociationType::Aggregation )
             m_pClearPoly->setBrush( QBrush( Qt::white ) );
         else
             m_pClearPoly->setBrush( QBrush( lineColor() ) );
-        m_pClearPoly->setZ( -1 );
+        m_pClearPoly->setZValue( -1 );
         break;
 
     case Uml::AssociationType::Containment:
         growList(m_HeadList, 1);
         if (!m_pCircle) {
             m_pCircle = new Circle( 6 );
-            m_pCircle->setCanvas( canvas() );
+            canvas()->addItem(m_pCircle);
             m_pCircle->show();
             m_pCircle->setPen( QPen( lineColor(), lineWidth() ) );
         }
@@ -1030,7 +1021,7 @@ void AssociationLine::createHeadLines()
 void AssociationLine::updateHead()
 {
     int count = m_HeadList.count();
-    UMLSceneLineItem * line = 0;
+    QGraphicsLineItem* line = 0;
 
     switch( getAssocType() ) {
     case Uml::AssociationType::State:
@@ -1042,10 +1033,10 @@ void AssociationLine::updateHead()
             return;
 
         line = m_HeadList.at( 0 );
-        line->setPoints( m_EgdePoint.x(), m_EgdePoint.y(), m_ArrowPointA.x(), m_ArrowPointA.y() );
+        line->setLine( m_EgdePoint.x(), m_EgdePoint.y(), m_ArrowPointA.x(), m_ArrowPointA.y() );
 
         line = m_HeadList.at( 1 );
-        line->setPoints( m_EgdePoint.x(), m_EgdePoint.y(), m_ArrowPointB.x(), m_ArrowPointB.y() );
+        line->setLine( m_EgdePoint.x(), m_EgdePoint.y(), m_ArrowPointB.x(), m_ArrowPointB.y() );
         break;
 
     case Uml::AssociationType::Relationship:
@@ -1060,12 +1051,12 @@ void AssociationLine::updateHead()
             else
                 yoffset = 8;
             line = m_HeadList.at( 0 );
-            line->setPoints( m_PointArray[2].x(), m_PointArray[2].y(),
-                             m_PointArray[0].x()-xoffset, m_PointArray[0].y()-yoffset );
+            line->setLine( m_PointArray[2].x(), m_PointArray[2].y(),
+                           m_PointArray[0].x()-xoffset, m_PointArray[0].y()-yoffset );
 
             line = m_HeadList.at( 1 );
-            line->setPoints( m_PointArray[2].x(), m_PointArray[2].y(),
-                             m_PointArray[0].x()+xoffset, m_PointArray[0].y()+yoffset );
+            line->setLine( m_PointArray[2].x(), m_PointArray[2].y(),
+                           m_PointArray[0].x()+xoffset, m_PointArray[0].y()+yoffset );
         }
 
     case Uml::AssociationType::Generalization:
@@ -1073,14 +1064,14 @@ void AssociationLine::updateHead()
         if( count < 3)
             return;
         line = m_HeadList.at( 0 );
-        line->setPoints( m_EgdePoint.x(), m_EgdePoint.y(), m_ArrowPointA.x(), m_ArrowPointA.y() );
+        line->setLine( m_EgdePoint.x(), m_EgdePoint.y(), m_ArrowPointA.x(), m_ArrowPointA.y() );
 
         line = m_HeadList.at( 1 );
-        line->setPoints( m_EgdePoint.x(), m_EgdePoint.y(), m_ArrowPointB.x(), m_ArrowPointB.y() );
+        line->setLine( m_EgdePoint.x(), m_EgdePoint.y(), m_ArrowPointB.x(), m_ArrowPointB.y() );
 
         line = m_HeadList.at( 2 );
-        line->setPoints( m_ArrowPointA.x(), m_ArrowPointA.y(), m_ArrowPointB.x(), m_ArrowPointB.y() );
-        m_pClearPoly->setPoints( m_PointArray );
+        line->setLine( m_ArrowPointA.x(), m_ArrowPointA.y(), m_ArrowPointB.x(), m_ArrowPointB.y() );
+        m_pClearPoly->setPolygon( m_PointArray );
         break;
 
     case Uml::AssociationType::Composition:
@@ -1088,25 +1079,25 @@ void AssociationLine::updateHead()
         if( count < 4)
             return;
         line = m_HeadList.at( 0 );
-        line->setPoints( m_PointArray[ 0 ].x(), m_PointArray[ 0 ].y(), m_PointArray[ 1 ].x(), m_PointArray[ 1 ].y() );
+        line->setLine( m_PointArray[ 0 ].x(), m_PointArray[ 0 ].y(), m_PointArray[ 1 ].x(), m_PointArray[ 1 ].y() );
 
         line = m_HeadList.at( 1 );
-        line->setPoints( m_PointArray[ 1 ].x(), m_PointArray[ 1 ].y(), m_PointArray[ 2 ].x(), m_PointArray[ 2 ].y() );
+        line->setLine( m_PointArray[ 1 ].x(), m_PointArray[ 1 ].y(), m_PointArray[ 2 ].x(), m_PointArray[ 2 ].y() );
 
         line = m_HeadList.at( 2 );
-        line->setPoints( m_PointArray[ 2 ].x(), m_PointArray[ 2 ].y(), m_PointArray[ 3 ].x(), m_PointArray[ 3 ].y() );
+        line->setLine( m_PointArray[ 2 ].x(), m_PointArray[ 2 ].y(), m_PointArray[ 3 ].x(), m_PointArray[ 3 ].y() );
 
         line = m_HeadList.at( 3 );
-        line->setPoints( m_PointArray[ 3 ].x(), m_PointArray[ 3 ].y(), m_PointArray[ 0 ].x(), m_PointArray[ 0 ].y() );
-        m_pClearPoly->setPoints( m_PointArray );
+        line->setLine( m_PointArray[ 3 ].x(), m_PointArray[ 3 ].y(), m_PointArray[ 0 ].x(), m_PointArray[ 0 ].y() );
+        m_pClearPoly->setPolygon( m_PointArray );
         break;
 
     case Uml::AssociationType::Containment:
         if (count < 1)
             return;
         line = m_HeadList.at( 0 );
-        line->setPoints( m_PointArray[ 1 ].x(), m_PointArray[ 1 ].y(),
-                         m_PointArray[ 3 ].x(), m_PointArray[ 3 ].y() );
+        line->setLine( m_PointArray[ 1 ].x(), m_PointArray[ 1 ].y(),
+                       m_PointArray[ 3 ].x(), m_PointArray[ 3 ].y() );
         m_pCircle->setX( m_MidPoint.x() );
         m_pCircle->setY( m_MidPoint.y() );
         break;
@@ -1124,8 +1115,8 @@ void AssociationLine::calculateParallelLine()
     double ATAN = atan(1.0);
     int lineDist = 10;
     //get  1/8(M) and 7/8(T) point
-    QPoint a = point( midCount - 1 );
-    QPoint b = point( midCount );
+    UMLScenePoint a = point( midCount - 1 );
+    UMLScenePoint b = point( midCount );
     int mx = ( a.x() + b.x() ) / 2;
     int my = ( a.y() + b.y() ) / 2;
     int tx = ( mx + b.x() ) / 2;
@@ -1139,7 +1130,7 @@ void AssociationLine::calculateParallelLine()
     //find point from M to start line from.
     double cosx = cos( angle ) * lineDist;
     double siny = sin( angle ) * lineDist;
-    QPoint pointM( mx + (int)cosx, my + (int)siny );
+    UMLScenePoint pointM( mx + (int)cosx, my + (int)siny );
     //find dist between P(xb, yb)
     distX = ( tx - b.x() );
     distX *= distX;
@@ -1148,7 +1139,7 @@ void AssociationLine::calculateParallelLine()
     //find point from T to end line
     cosx = cos( angle ) * lineDist;
     siny = sin( angle ) * lineDist;
-    QPoint pointT( tx + (int)cosx, ty + (int)siny );
+    UMLScenePoint pointT( tx + (int)cosx, ty + (int)siny );
     m_ParallelLines[ 1 ] = pointM;
     m_ParallelLines[ 0 ] = pointT;
 
@@ -1184,19 +1175,19 @@ void AssociationLine::updateParallelLine()
 {
     if( !m_bParallelLineCreated )
         return;
-    UMLSceneLineItem * line = 0;
-    QPoint common = m_ParallelLines.at( 0 );
-    QPoint p = m_ParallelLines.at( 1 );
+    QGraphicsLineItem* line = 0;
+    UMLScenePoint common = m_ParallelLines.at( 0 );
+    UMLScenePoint p = m_ParallelLines.at( 1 );
     line = m_ParallelList.at( 0 );
-    line->setPoints( common.x(), common.y(), p.x(), p.y() );
+    line->setLine( common.x(), common.y(), p.x(), p.y() );
 
     p = m_ParallelLines.at( 2 );
     line = m_ParallelList.at( 1 );
-    line->setPoints( common.x(), common.y(), p.x(), p.y() );
+    line->setLine( common.x(), common.y(), p.x(), p.y() );
 
     p = m_ParallelLines.at( 3 );
     line = m_ParallelList.at( 2 );
-    line->setPoints( common.x(), common.y(), p.x(), p.y() );
+    line->setLine( common.x(), common.y(), p.x(), p.y() );
 }
 
 /**
@@ -1211,7 +1202,7 @@ void AssociationLine::createSubsetSymbol()
     switch( getAssocType() ) {
        case Uml::AssociationType::Child2Category:
            m_pSubsetSymbol = new SubsetSymbol;
-           m_pSubsetSymbol->setCanvas(canvas());
+           canvas()->addItem(m_pSubsetSymbol);
            m_pSubsetSymbol->setPen( QPen( lineColor(), lineWidth() ) );
            updateSubsetSymbol();
            m_pSubsetSymbol->show();
@@ -1231,10 +1222,10 @@ void AssociationLine::updateSubsetSymbol()
     if ( m_LineList.count() < 1 ) {
         return;
     }
-    UMLSceneLineItem* firstLine = m_LineList.first();
-    QPoint startPoint = firstLine->startPoint();
-    QPoint endPoint = firstLine->endPoint();
-    QPoint centrePoint;
+    QGraphicsLineItem* firstLine = m_LineList.first();
+    UMLScenePoint startPoint = firstLine->line().p1();
+    UMLScenePoint endPoint = firstLine->line().p2();
+    UMLScenePoint centrePoint;
     centrePoint.setX( ( startPoint.x() + endPoint.x() )/2 );
     centrePoint.setY( ( startPoint.y() + endPoint.y() )/2 );
 
@@ -1275,9 +1266,9 @@ void AssociationLine::growList(LineList &list, int by)
 {
     QPen pen( lineColor(), lineWidth() );
     for (int i = 0; i < by; i++) {
-        UMLSceneLineItem * line = new UMLSceneLineItem;
-        line->setCanvas(canvas());
-        line->setZ( 0 );
+        QGraphicsLineItem* line = new QGraphicsLineItem;
+        canvas()->addItem(line);
+        line->setZValue( 0 );
         line->setPen( pen );
         line->setVisible( true );
         list.append( line );
