@@ -25,14 +25,16 @@
 #include "uniqueid.h"
 
 //qt includes
-#include <QPolygon>
 #include <QMoveEvent>
+#include <QPainter>
+#include <QPolygon>
 #include <QResizeEvent>
-#include <QtGui/QPainter>
 
 //kde includes
 #include <klocale.h>
 
+DEBUG_REGISTER_DISABLED(MessageWidget)
+
 /**
  * Constructs a MessageWidget.
  *
@@ -154,7 +156,7 @@ void MessageWidget::updateResizability()
 /**
  * Calls drawSynchronous() or drawAsynchronous().
  */
-void MessageWidget::paint(QPainter& p, int offsetX, int offsetY)
+void MessageWidget::draw(QPainter& p, int offsetX, int offsetY)
 {
     if(!m_pOw[Uml::A] || !m_pOw[Uml::B]) {
         return;
@@ -455,7 +457,7 @@ void MessageWidget::drawFound(QPainter& p, int offsetX, int offsetY)
  *         between call line and return line does not count, i.e. if
  *         the point is located in that space the function returns 0.
  */
-int MessageWidget::onWidget(const QPoint & p)
+UMLSceneValue MessageWidget::onWidget(const UMLScenePoint& p)
 {
     if (m_sequenceMessageType != Uml::sequence_message_synchronous) {
         return UMLWidget::onWidget(p);
@@ -483,13 +485,13 @@ int MessageWidget::onWidget(const QPoint & p)
 void MessageWidget::setTextPosition()
 {
     if (m_pFText == NULL) {
-        uDebug() << "m_pFText is NULL";
+        DEBUG(DBG_SRC) << "m_pFText is NULL";
         return;
     }
     if (m_pFText->displayText().isEmpty()) {
         return;
     }
-    m_pFText->updateComponentSize();
+    m_pFText->updateGeometry();
     int ftX = constrainX(m_pFText->x(), m_pFText->width(), m_pFText->textRole());
     int ftY = y() - m_pFText->height();
     m_pFText->setX( ftX );
@@ -532,13 +534,13 @@ int MessageWidget::constrainX(int textX, int textWidth, Uml::TextRole tr)
  * @param textHeight   height of the text
  * @param tr           Uml::TextRole of the text
  */
-void MessageWidget::constrainTextPos(int &textX, int &textY, int textWidth, int textHeight,
+void MessageWidget::constrainTextPos(UMLSceneValue &textX, UMLSceneValue &textY, UMLSceneValue textWidth, UMLSceneValue textHeight,
                                      Uml::TextRole tr)
 {
     textX = constrainX(textX, textWidth, tr);
     // Constrain Y.
-    const int minTextY = getMinY();
-    const int maxTextY = getMaxY() - textHeight - 5;
+    const UMLSceneValue minTextY = getMinY();
+    const UMLSceneValue maxTextY = getMaxY() - textHeight - 5;
     if (textY < minTextY)
         textY = minTextY;
     else if (textY > maxTextY)
@@ -558,9 +560,9 @@ void MessageWidget::setLinkAndTextPos()
     }
 }
 
-void MessageWidget::moveEvent(QMoveEvent* /*m*/)
+void MessageWidget::moveEvent(QGraphicsSceneMouseEvent* /*m*/)
 {
-    //uDebug() << "m_pFText is " << m_pFText;
+    //DEBUG(DBG_SRC) << "m_pFText is " << m_pFText;
     if (!m_pFText) {
         return;
     }
@@ -597,7 +599,7 @@ void MessageWidget::slotWidgetMoved(Uml::IDType id)
     const Uml::IDType idA = m_pOw[Uml::A]->localID();
     const Uml::IDType idB = m_pOw[Uml::B]->localID();
     if (idA != id && idB != id) {
-        uDebug() << "id=" << ID2STR(id) << ": ignoring for idA=" << ID2STR(idA)
+        DEBUG(DBG_SRC) << "id=" << ID2STR(id) << ": ignoring for idA=" << ID2STR(idA)
             << ", idB=" << ID2STR(idB);
         return;
     }
@@ -620,7 +622,7 @@ void MessageWidget::slotWidgetMoved(Uml::IDType id)
  * @param w The ObjectWidget to check for.
  * @return  true - if is contained, false - not contained.
  */
-bool MessageWidget::contains(ObjectWidget * w)
+bool MessageWidget::hasObjectWidget(ObjectWidget * w)
 {
     if(m_pOw[Uml::A] == w || m_pOw[Uml::B] == w)
         return true;
@@ -651,12 +653,12 @@ bool MessageWidget::activate(IDChangeLog * /*Log = 0*/)
     if (m_pOw[Uml::A] == NULL) {
         UMLWidget *pWA = m_scene->findWidget(m_widgetAId);
         if (pWA == NULL) {
-            uDebug() << "role A object " << ID2STR(m_widgetAId) << " not found";
+            DEBUG(DBG_SRC) << "role A object " << ID2STR(m_widgetAId) << " not found";
             return false;
         }
         m_pOw[Uml::A] = dynamic_cast<ObjectWidget*>(pWA);
         if (m_pOw[Uml::A] == NULL) {
-            uDebug() << "role A widget " << ID2STR(m_widgetAId)
+            DEBUG(DBG_SRC) << "role A widget " << ID2STR(m_widgetAId)
                 << " is not an ObjectWidget";
             return false;
         }
@@ -664,12 +666,12 @@ bool MessageWidget::activate(IDChangeLog * /*Log = 0*/)
     if (m_pOw[Uml::B] == NULL) {
         UMLWidget *pWB = m_scene->findWidget(m_widgetBId);
         if (pWB == NULL) {
-            uDebug() << "role B object " << ID2STR(m_widgetBId) << " not found";
+            DEBUG(DBG_SRC) << "role B object " << ID2STR(m_widgetBId) << " not found";
             return false;
         }
         m_pOw[Uml::B] = dynamic_cast<ObjectWidget*>(pWB);
         if (m_pOw[Uml::B] == NULL) {
-            uDebug() << "role B widget " << ID2STR(m_widgetBId)
+            DEBUG(DBG_SRC) << "role B widget " << ID2STR(m_widgetBId)
                 << " is not an ObjectWidget";
             return false;
         }
@@ -802,7 +804,7 @@ UMLClassifier *MessageWidget::operationOwner()
  */
 UMLOperation *MessageWidget::operation()
 {
-    return static_cast<UMLOperation*>(m_pObject);
+    return static_cast<UMLOperation*>(m_umlObject);
 }
 
 /**
@@ -811,11 +813,11 @@ UMLOperation *MessageWidget::operation()
  */
 void MessageWidget::setOperation(UMLOperation *op)
 {
-    if (m_pObject && m_pFText)
-        disconnect(m_pObject, SIGNAL(modified()), m_pFText, SLOT(setMessageText()));
-    m_pObject = op;
-    if (m_pObject && m_pFText)
-        connect(m_pObject, SIGNAL(modified()), m_pFText, SLOT(setMessageText()));
+    if (m_umlObject && m_pFText)
+        disconnect(m_umlObject, SIGNAL(modified()), m_pFText, SLOT(setMessageText()));
+    m_umlObject = op;
+    if (m_umlObject && m_pFText)
+        connect(m_umlObject, SIGNAL(modified()), m_pFText, SLOT(setMessageText()));
 }
 
 /**
