@@ -4,18 +4,18 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006                                                    *
+ *   copyright (C) 2006-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef WIDGET_FACTORY_H
 #define WIDGET_FACTORY_H
 
-#include <qstring.h>
+#include <QString>
 
 // forward declarations
-class UMLScene;
 class UMLObject;
+class UMLScene;
 class UMLWidget;
 
 /**
@@ -24,14 +24,8 @@ class UMLWidget;
  */
 namespace Widget_Factory {
 
-    /**
-     * Create a UMLWidget in the given view and representing the given document object.
-     */
     UMLWidget *createWidget(UMLScene *scene, UMLObject *docObj);
 
-    /**
-     * Create a UMLWidget according to the given XMI tag.
-     */
     UMLWidget* makeWidgetFromXMI(const QString& tag,
                                  const QString& idStr, UMLScene *scene);
 
